Class: MusicBrainz::Model::Label

Inherits:
Individual show all
Includes:
Taggable
Defined in:
lib/rbrainz/model/label.rb

Overview

Constant Summary collapse

TYPE_UNKNOWN =

Used if the type of the label is unknown.

NS_MMD_1 + 'Unknown'
TYPE_DISTRIBUTOR =

Companies mainly distributing other labels production, usually in a specific region of the world.

NS_MMD_1 + 'Distributor'
TYPE_HOLDING =

Holdings, conglomerates or other financial entities whose main activity is not to produce records, but to manage a large set of recording labels owned by them.

NS_MMD_1 + 'Holding'
TYPE_ORIGINAL_PRODUCTION =

Recording labels producing entirely new releases.

NS_MMD_1 + 'OriginalProduction'
TYPE_BOOTLEG_PRODUCTION =

Bootlegs companies (as in “not sanctioned by the rights owner(s) of the released work”)

NS_MMD_1 + 'BootlegProduction'
TYPE_REISSUE_PRODUCTION =

Labels specializing in catalog reissues.

NS_MMD_1 + 'ReissueProduction'
ENTITY_TYPE =

See Entity::ENTITY_TYPE.

:label

Instance Attribute Summary collapse

Attributes inherited from Individual

#aliases, #begin_date, #disambiguation, #end_date, #name, #releases, #sort_name, #type

Attributes included from Rateable

#rating, #user_rating

Attributes inherited from Entity

#id

Method Summary

Methods included from Taggable

#tags, #user_tags

Methods inherited from Individual

#initialize, #to_s, #unique_name

Methods included from Relateable

#add_relation, #get_relations, #relation_target_types

Methods inherited from Entity

#entity_type, entity_type, #initialize

Constructor Details

This class inherits a constructor from MusicBrainz::Model::Individual

Instance Attribute Details

#codeObject

The code of the label.

See

musicbrainz.org/doc/LabelCode



55
56
57
# File 'lib/rbrainz/model/label.rb', line 55

def code
  @code
end

#countryObject

The country in which the company was founded. A string containing a ISO 3166 country code like ‘GB’, ‘US’ or ‘DE’.

See

Utils#get_country_name

See

musicbrainz.org/doc/LabelCountry



63
64
65
# File 'lib/rbrainz/model/label.rb', line 63

def country
  @country
end