Module: MusicBrainz::Model::Taggable

Included in:
Individual, Label, Release, Track
Defined in:
lib/rbrainz/model/taggable.rb

Overview

Mixin module to add folksonomy tagging capabilities to Entity classes.

see

Tag

Instance Method Summary collapse

Instance Method Details

#tagsObject

Returns a Collection of Tag objects assigned to this entity.



20
21
22
# File 'lib/rbrainz/model/taggable.rb', line 20

def tags
  @tags ||= Collection.new
end

#user_tagsObject

Returns a Collection of Tag objects assigned to this entity by the current user.



25
26
27
# File 'lib/rbrainz/model/taggable.rb', line 25

def user_tags
  @user_tags ||= Collection.new
end