Class: MusicBrainz::Webservice::ArtistFilter
- Inherits:
-
AbstractFilter
- Object
- AbstractFilter
- MusicBrainz::Webservice::ArtistFilter
- Defined in:
- lib/rbrainz/webservice/filter.rb
Overview
A filter for the artist collection.
Instance Method Summary collapse
-
#initialize(filter) ⇒ ArtistFilter
constructor
The parameter filter is a hash with filter options.
Methods inherited from AbstractFilter
Constructor Details
#initialize(filter) ⇒ ArtistFilter
The parameter filter is a hash with filter options. At least the :name or :query filter must be specified.
Available filter options: [:name] Fetch a list of artists with a matching name. [:limit] The maximum number of artists returned. Defaults to 25, the maximum allowed value is 100. [:offset] Return search results starting at a given offset. Used for paging through more than one page of results. [:query] A Lucene search query. The query parameter is a search string which will be passed to the underlying Lucene search engine. It must follow the syntax described in http://musicbrainz.org/doc/TextSearchSyntax.
66 67 68 69 70 |
# File 'lib/rbrainz/webservice/filter.rb', line 66 def initialize(filter) Utils. filter, :name, :limit, :offset, :query super(filter) @filter[:name] = filter[:name] if filter[:name] end |