Class: MusicBrainz::Model::Label
- Inherits:
-
Individual
- Object
- Entity
- Individual
- MusicBrainz::Model::Label
- Includes:
- Taggable
- Defined in:
- lib/rbrainz/model/label.rb
Overview
A label in the MusicBrainz DB.
Labels in MusicBrainz can have a type. Currently, the following types are supported
- See
-
Individual
- See
Constant Summary collapse
- TYPE_UNKNOWN =
Used if the type of the label is unknown.
NS_MMD_1 + 'Unknown'
- TYPE_DISTRIBUTOR =
Companies mainly distributing other labels production, usually in a specific region of the world.
NS_MMD_1 + 'Distributor'
- TYPE_HOLDING =
Holdings, conglomerates or other financial entities whose main activity is not to produce records, but to manage a large set of recording labels owned by them.
NS_MMD_1 + 'Holding'
- TYPE_ORIGINAL_PRODUCTION =
Recording labels producing entirely new releases.
NS_MMD_1 + 'OriginalProduction'
- TYPE_BOOTLEG_PRODUCTION =
Bootlegs companies (as in “not sanctioned by the rights owner(s) of the released work”)
NS_MMD_1 + 'BootlegProduction'
- TYPE_REISSUE_PRODUCTION =
Labels specializing in catalog reissues.
NS_MMD_1 + 'ReissueProduction'
- ENTITY_TYPE =
See Entity::ENTITY_TYPE.
:label
Instance Attribute Summary collapse
-
#code ⇒ Object
The code of the label.
-
#country ⇒ Object
The country in which the company was founded.
Attributes inherited from Individual
#aliases, #begin_date, #disambiguation, #end_date, #name, #releases, #sort_name, #type
Attributes included from Rateable
Attributes inherited from Entity
Method Summary
Methods included from Taggable
Methods inherited from Individual
#initialize, #to_s, #unique_name
Methods included from Relateable
#add_relation, #get_relations, #relation_target_types
Methods inherited from Entity
#entity_type, entity_type, #initialize
Constructor Details
This class inherits a constructor from MusicBrainz::Model::Individual
Instance Attribute Details
#code ⇒ Object
The code of the label.
55 56 57 |
# File 'lib/rbrainz/model/label.rb', line 55 def code @code end |
#country ⇒ Object
The country in which the company was founded. A string containing a ISO 3166 country code like ‘GB’, ‘US’ or ‘DE’.
- See
-
Utils#get_country_name
- See
63 64 65 |
# File 'lib/rbrainz/model/label.rb', line 63 def country @country end |