Module: MusicBrainz::Model::Taggable
- Included in:
- Individual, Label, Release, Track
- Defined in:
- lib/rbrainz/model/taggable.rb
Overview
Mixin module to add folksonomy tagging capabilities to Entity classes.
- see
-
Tag
Instance Method Summary collapse
-
#tags ⇒ Object
Returns a Collection of Tag objects assigned to this entity.
-
#user_tags ⇒ Object
Returns a Collection of Tag objects assigned to this entity by the current user.
Instance Method Details
#tags ⇒ Object
Returns a Collection of Tag objects assigned to this entity.
20 21 22 |
# File 'lib/rbrainz/model/taggable.rb', line 20 def ||= Collection.new end |
#user_tags ⇒ Object
Returns a Collection of Tag objects assigned to this entity by the current user.
25 26 27 |
# File 'lib/rbrainz/model/taggable.rb', line 25 def ||= Collection.new end |