Exception: MusicBrainz::Webservice::AuthenticationError
- Inherits:
-
WebserviceError
- Object
- Exception
- WebserviceError
- MusicBrainz::Webservice::AuthenticationError
- Defined in:
- lib/rbrainz/webservice.rb
Overview
Client requested a resource which requires authentication via HTTP Digest Authentication.
If sent even though user name and password were given: user name and/or password are incorrect.