Class: MusicBrainz::Webservice::LabelFilter
- Inherits:
-
AbstractFilter
- Object
- AbstractFilter
- MusicBrainz::Webservice::LabelFilter
- Defined in:
- lib/rbrainz/webservice/filter.rb
Overview
A filter for the label collection.
Instance Method Summary collapse
-
#initialize(filter) ⇒ LabelFilter
constructor
The parameter filter is a hash with filter options.
Methods inherited from AbstractFilter
Constructor Details
#initialize(filter) ⇒ LabelFilter
The parameter filter is a hash with filter options. At least the :name or :query filter must be specified.
Available filter options: [:name] Fetch a list of labels with a matching name. [:limit] The maximum number of labels returned. Defaults to 25, the maximum allowed value is 100. [:offset] Return search results starting at a given offset. Used for paging through more than one page of results. [:query] A Lucene search query. The query parameter is a search string which will be passed to the underlying Lucene search engine. It must follow the syntax described in http://musicbrainz.org/doc/TextSearchSyntax.
246 247 248 249 250 |
# File 'lib/rbrainz/webservice/filter.rb', line 246 def initialize(filter) Utils. filter, :limit, :offset, :query, :name super(filter) @filter[:name] = filter[:name] if filter[:name] end |